<?php

/**
 * @file
 * Builds placeholder replacement tokens for webforms and submissions.
 */

use Drupal\Core\Render\BubbleableMetadata;

/**
 * Implements hook_token_info().
 */
function file_download_token_webform_token_info_alter(&$data) {
  $data['tokens']['webform']['file-download-token-url'] = [
    'name' => t('Webform file download url'),
    'description' => t('Displays a file download token link if one is specified for this webform in an email handler.'),
  ];
}

/**
 * Implements hook_tokens().
 */
function file_download_token_webform_tokens($type, $tokens, array $data, array $options, BubbleableMetadata $bubbleable_metadata) {
  $replacements = [];
  if ($type !== 'webform' || empty($data['webform'])) {
    return [];
  }

  /** @var \Drupal\webform\WebformInterface $webform */
  $webform = $data['webform'];

  $settings = $webform->getThirdPartySettings('file_download_token_webform');
  if (empty($settings) || empty($settings['download_token_file'])) {
    return [];
  }

  foreach ($tokens as $name => $original) {
    if ($name !== 'file-download-token-url') {
      continue;
    }

    $entity_type_manager = \Drupal::entityTypeManager()->getStorage('file');
    $download_token_manager = \Drupal::service('file_download_token.download_token_manager');

    if ($file = $entity_type_manager->load($settings['download_token_file'])) {
      $replacements[$original] = $download_token_manager->createTokenLink($file)->toString();
    }
  }

  return $replacements;
}
