<?php

namespace Drupal\file_download_token;

use Drupal\file\FileInterface;

/**
 * Defines interface for download token manager classes.
 */
interface DownloadTokenManagerInterface {

  /**
   * Creates the download token.
   *
   * @param \Drupal\file\FileInterface $file
   *   The file to be downloaded.
   *
   * @return string
   *   The token.
   */
  public function createToken(FileInterface $file);

  /**
   * Creates the token url.
   *
   * @param \Drupal\file\FileInterface $file
   *   The file to be downloaded.
   *
   * @return \Drupal\Core\Url
   *   The token URL.
   */
  public function createTokenUrl(FileInterface $file);

  /**
   * Creates the token link.
   *
   * @param \Drupal\file\FileInterface $file
   *   The file to be downloaded.
   *
   * @return \Drupal\Core\Link
   *   The token link.
   */
  public function createTokenLink(FileInterface $file);

  /**
   * Generates the token.
   *
   * @return string
   *   The token.
   */
  public function generateToken();

  /**
   * Returns the downloadable file if the token is correct.
   *
   * @param string $token
   *   The token.
   *
   * @return \Drupal\file\FileInterface|null
   *   The file.
   */
  public function getFile(string $token);

  /**
   * Deletes invalid tokens.
   */
  public function cleanupTokens();

}
